Overviews – Samplics Documentation
Description: Documentation of the Python package Samplics for statistical design and analysis of complex samples

# Overviews

When a sample frame is available, the simple random sampling (srs) method is usually the easiest way to select a sample. However, operational and cost constraints often result in much more complex mechanisms for selecting samples. Common use cases of complex sampling designs are the national household surveys such as The Demographic and Health Surveys (DHS), The Living Standards Measurement Study (LSMS), The Multiple Indicator Cluster Surveys (MICS), and many more. In the national household surveys, the sample is selected in stages. For example, at the first stage clusters of households are selected using probability proportional to size (pps) method, at the second stage households are selected from the sampled clusters, and at the final stage individuals are selected from households in the sample.

In this tutorial, we generate simulated data to illustrate the first and second stage selections of clusters and households, respectively.

Section 1: Selection of PSUs
Section 2: Selection of SSUs

For a comprehensive review of sampling techniques, users may want to consult Brewer and Hanif (1983), Cochran (1977), Kish (1965), and Lohr (2021).

## References

Brewer, K. R. W., and M Hanif. 1983. Sampling With Unequal Probabilities. Springer-Verlag New York, Inc. https://doi.org/10.1007/9781468494075.
Cochran, William G. 1977. Sampling Techniques, 3rd edn. John Wiley & Sons, Inc.
Kish, Leslie. 1965. Survey Sampling. John Wiley & Sons, Inc.
Lohr, Sharon L. 2021. Sampling: Design and Analysis, Third Edition. Chapman; Hall/CRC. https://doi.org/https://doi.org/10.1201/9780429298899.